@@ -45,7 +45,8 @@
                               levRestriction=levRestriction),
                     treatmentName='Deviation Fact',
                     treatmentCode='catD',
-                    needsSplit=TRUE)
+                    needsSplit=TRUE,
+                    extraModelDegrees=max(0,length(scores)-1))
   pred <- treatment$f(vcolin,treatment$args)
   if(!.has.range.cn(pred)) {
     return(NULL)
